<?php

include_once(dirname(__FILE__).'/../../Base/HTML/AddWebObject.php');
include_once(dirname(__FILE__).'/../../Base/HTML/EditWebObject.php');
include_once(dirname(__FILE__).'/../../Base/HTML/ViewWebObject.php');
include_once(dirname(__FILE__).'/../../Base/HTML/ListWebObject.php');
include_once(dirname(__FILE__).'/../../Base/HTML/Controller.php');
include_once(dirname(__FILE__).'/../Lift/Controller.php');

class UserLoginWebObject extends AddWebObject
{
  function  __construct($System)
  {
    parent::__construct($System);
    $this->Columns = array(
      'UserName' => array(
        'Type' => 'String',
      ),
      'Password' => array(
        'Type' => 'Password',
      ),
    );
    $this->Groups = array(
      'UserLogin',
    );
    $this->Actions = array(
      array('Name' => 'UserLogin', 'Module' => 'User', 'Action' => 'Login'),
    );
  }

  function AddProcessRow($Row)
  {
    return($Row);
  }
}

class UserEditWebObject extends EditWebObject
{
  function  __construct($System)
  {
    parent::__construct($System);
    $this->Table = 'User';
    $this->SQL = 'SELECT * FROM User';
    $this->Columns = array(
      'UserName' => array(
        'Type' => 'String',
        'SQL' => 'Name',
        'ReadOnly' => true,
      ),
      'Password' => array(
        'Type' => 'Password',
        'SQL' => 'Password',
        'ReadOnly' => false,
      ),
      'FullName' => array(
        'Type' => 'String',
        'SQL' => 'FullName',
        'ReadOnly' => false,
        'Group' => 1,
      ),
      'Email' => array(
        'Type' => 'String',
        'SQL' => 'Email',
        'ReadOnly' => false,
        'Group' => 1,
      ),
    );
    $this->Groups = array(
      'UserLogin',
      'UserDetails',
    );
    $this->Actions = array(
      array('Name' => 'Save', 'Module' => 'User', 'Action' => 'Edit'),
    );
  }

  function SaveProcessRow($Row)
  {
    if($Row['Password'] != '""')
    {
      $Salt = $this->System->User->GetPasswordSalt();
      $Row['Salt'] = '"'.$Salt.'"';
      $Row['Password'] = 'SHA1(CONCAT("'.substr($Row['Password'], 1, -1).'", "'.$Salt.'"))';
    } else unset($Row['Password']);
    return($Row);
  }
}

class UserViewWebObject extends ViewWebObject
{
  function  __construct($System)
  {
    parent::__construct($System);
    $this->Table = 'User';
    $this->SQLJoin = '';
    $this->Columns = array(
      'UserName' => array(
        'Type' => 'String',
        'SQL' => 'Name',
        'ReadOnly' => true,
      ),
      'Password' => array(
        'Type' => 'Password',
        'SQL' => 'Password',
        'ReadOnly' => false,
      ),
      'Member' => array(
        'Type' => 'PointerToMember',
        'SQL' => 'Member',
        'ReadOnly' => true,
      ),
      'FullName' => array(
        'Type' => 'String',
        'SQL' => 'FullName',
        'ReadOnly' => false,
        'Group' => 1,
      ),
      'Email' => array(
        'Type' => 'String',
        'SQL' => 'Email',
        'ReadOnly' => false,
        'Group' => 1,
      ),
    );
    $this->Groups = array(
      'UserLogin',
      'UserDetails',
    );
    $this->Actions = array(
      array('Name' => 'Save', 'Module' => 'User', 'Action' => 'Edit'),
    );
  }

  function AddProcessRow($Row)
  {
    return($Row);
  }
}

class UserListWebObject extends ListWebObject
{
  function  __construct($System)
  {
    parent::__construct($System);
    $this->Table = 'User';
    $this->SQLJoin = 'WHERE Company='.$this->System->User->Data['Company'];
    $this->DefaultOrder = array(
      array('Column' => 'UserName', 'Direction' => 0),
    );
    $this->Columns = array(
     'UserName' => array(
        'Type' => 'String',
        'SQL' => 'Name',
        'ReadOnly' => true,
      ),
      'FullName' => array(
        'Type' => 'String',
        'SQL' => 'FullName',
        'ReadOnly' => false,
        'Group' => 1,
      ),
      'Email' => array(
        'Type' => 'String',
        'SQL' => 'Email',
        'ReadOnly' => false,
        'Group' => 1,
      ),
    );
    $this->Actions = array(
      array('Name' => 'View', 'Module' => 'User', 'Action' => 'View'),
    );
  }
}

class UserController extends Controller
{
  function  __construct($System)
  {
    parent::__construct($System);
    $this->Name = 'User';
    $this->DefaultAction = 'Login';
    $this->ActionMap = array(
      'View' => 'View',
      //'Delete' => 'Delete',
      'Edit' => 'Edit',
      //'Add' => 'Add',
      'Logout' => 'Logout',
      'Login' => 'Login',
      'ListPanel' => 'ListPanel',
      'List' => 'ItemList',
    );
  }
  function Login()
  {
    $Output = '';
    if(array_key_exists('Mode', $_GET)) $Mode = $_GET['Mode'];
      else $Mode = '';
    if($Mode == 'Store')
    {
      $this->System->Navigation->UnsetParameter('Mode');
      try {
        $UserId = $this->System->User->GetByNamePassword($_POST['UserName'], $_POST['Password']);
        $this->System->UserOnline->Login($UserId);
        $this->System->User->Id = $this->System->UserOnline->User;
        $this->System->User->LoadData();
        
        $_GET['M'] = $this->System->DefaultModule;
        unset($_GET['A']);
        $_GET['Panel'] = 1;
        $Output = $this->System->GetModuleOutput();
      } catch (UserNotFoundException $E)
      {
        $Output .= $this->System->Output->SystemMessage($this->System->Localization->Translate('UserNotFound'));
      }
    } else
    {
      $LiftItem = new UserLoginWebObject($this->System);
      $Output .= $this->System->HTML->Panel($this->System->Localization->Translate('UserLogin'),
        $LiftItem->Show());
    }
    return($Output);
  }

  function Logout()
  {
    $this->System->UserOnline->Logout();
    $this->System->User->Id = $this->System->UserOnline->User;
    $this->System->User->LoadData();
    $Output = $this->System->Output->SystemMessage($this->System->Localization->Translate('UserLoggedOut'));
    return($Output);
  }
}

?>
